<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box">
      <div class="drag-left">
        <!--左侧div内容-->
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu" />九小场所分类
          </div>
          <div class="common-tree-content">
            <div :class="['name-total',querys[5].value === item.dictValue ? 'active-item' : '']" v-for="(item,index) in classifyTreeList" :key="index" @click="handleItemClick(item.dictValue)">
              <div class="name">{{ item.dictName  }}</div>
              <div class="total">{{ item.totalNum }}</div>
            </div>
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏"></div>
      <div class="drag-mid">
        <!--右侧div内容-->
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <!-- <el-col :span="5">
                    <el-form-item label="所属片区">
                      <el-select v-model="querys[3].value" style="width:100%" clearable placeholder="请选择所属片区">
                        <el-option v-for="item in jxcspqList" :key="item.value" :label="item.name"
                          :value="item.value" />
                      </el-select>
                    </el-form-item>
                  </el-col> -->
                  <el-col :span="6">
                    <el-form-item label="商户名称">
                      <el-input v-model="querys[0].value" clearable placeholder="请输入商户名称" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="法人/负责人">
                      <el-input v-model="querys[1].value" clearable placeholder="请输入负责人" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="经营状态">
                      <el-select v-model="querys[4].value" style="width:100%" clearable>
                        <el-option v-for="item in jyztList" :key="item.value" :label="item.name" :value="item.value" />
                      </el-select>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
                    </el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">重置
                    </el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div ref="contentPanel" class="bbsl-table-content">
              <div ref="btnPanel" class="bbsl-btn-content">
                <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增
                </el-button>
                <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
                  <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
                    style="margin-left: 10px">删除
                  </el-button>
                </el-popconfirm>
              </div>
              <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
                <el-table-column type="selection" width="55" />
                <el-table-column type="index" width="55" label="序号" />
                <!-- <el-table-column prop="region" min-width="100" label="所属区域" show-overflow-tooltip /> -->
                <el-table-column min-width="120" prop="unitName" label="商户名称" show-overflow-tooltip />
                <el-table-column width="80" prop="employees" label="员工数量" show-overflow-tooltip />
                <el-table-column prop="riskLevelName" label="风险级别" show-overflow-tooltip />
                <el-table-column prop="fuelTypeName" label="燃气种类" show-overflow-tooltip />
                <el-table-column prop="name" label="负责人" show-overflow-tooltip/>
                <el-table-column min-width="100" prop="phone" label="联系电话" show-overflow-tooltip>
                  <template v-slot="{ row }">
                    {{ row.phone.slice(0, 3) + '****' + row.phone.slice(row.phone.length - 4) }}
                  </template>
                </el-table-column>
                <el-table-column min-width="155" prop="unitAddress" label="坐落地址" show-overflow-tooltip />
                <el-table-column width="80" prop="status" label="经营状态" show-overflow-tooltip />
              </el-table>
              <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total" @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </div>
            <nineLittlePlaceDialog ref="formModal" />
          </div>
        </div>
      </div>
    </div>
  </div>

</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import nineLittlePlaceApi from '@/views/Manage/saftyDanger/api/nineLittlePlaceApi'
import nineLittlePlaceDialog from '@/views/Manage/saftyDanger/components/nineLittlePlaceDialog'

export default {
  name: 'nineLittlePlace',
  components: {
    nineLittlePlaceDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyDangerUnit/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'unit_name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'type_',
          relation: 'AND',
          value: '1'
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'small_place_area_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'status_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'small_Place_Type_',
          relation: 'AND',
          value: ''
        },
      ],
      StshowFormDias: false,
      types: [],
      sorter: [
        {
          direction: 'DESC',
          property: 'createTime'
        }
      ],
      classifyTreeList: []
      // levels:[]
    }
  },
  created() {
    this.getStatisticsData()
    this.types = dictContracts.getDictItemsFromCache('cmgt_aqyhpcdwlb')
    this.fxjbList = dictUtils.getDictItemsFromCache('fxjb') //风险级别
    this.zddwflList = dictUtils.getDictItemsFromCache('zddwfl') //重点单位分类
    this.jxcslxList = dictUtils.getDictItemsFromCache('jxcslx') //九小场所类型
    this.jxcspqList = dictUtils.getDictItemsFromCache('jxcspq') //九小场所片区
    this.rlzlList = dictUtils.getDictItemsFromCache('rlzl') //燃料种类
    this.tysfList = dictUtils.getDictItemsFromCache('ty-sf') //是否三合一
    this.jyztList = dictUtils.getDictItemsFromCache('jyzt') //经营状态
    // this.levels = dictContracts.getDictItemsFromCache('cmgt_aqyhfxjb')
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      // this.querys[2].value = ''
      this.querys[3].value = ''
      this.querys[4].value = ''
      this.querys[5].value = ''
    },
    getStatisticsData() {
      this.classifyTreeList = []
      nineLittlePlaceApi.getStatisticsData('1',res => {
        if (res.state) {
          res.value.forEach(item => {
            if (item.dictName === '总计') {
              item.dictValue = ''
            }
          })
          this.classifyTreeList = res.value.sort((a,b) => b.totalNum - a.totalNum)
        }
      })
    },
    handleItemClick(val) {
      this.querys[5].value = val || ''
      this.loadData(1)
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      if (this.querys[4].value) {
        this.queryParam.querys.push(this.querys[4])
      }
      if (this.querys[5].value) {
        this.queryParam.querys.push(this.querys[5])
      }
      nineLittlePlaceApi.loadCmgtSaftyDangerUnit(this.queryParam).then(res => {
        this.total = res.data.total
        this.tableData = res.data.rows
        this.tableData.forEach(item => {
          this.jxcspqList.forEach(val => {
            if (item.smallPlaceArea == val.value) {
              item['smallPlaceAreaName'] = val.name
            }
          })
          item['emphasisTypeName'] = ''
          this.zddwflList.forEach(val => {
            if (item.emphasisType) {
              item.emphasisType.split(',').forEach((e, ei) => {
                if (e == val.value) {
                  if (ei + 1 < item.emphasisType.split(',').length) {
                    item['emphasisTypeName'] += val.name + ','
                  } else {
                    item['emphasisTypeName'] += val.name
                  }
                }
              })
            }
          })
          this.fxjbList.forEach(val => {
            if (item.riskLevel === val.value) {
              item['riskLevelName'] = val.name
            }
          })
          this.jyztList.forEach(val => {
            if (item.status == val.value) {
              item['status'] = val.name
            }
          })

          if (item.fuelType) {
            item.fuelTypeName = item.fuelType.split(',').flatMap(i => {
              return (this.rlzlList.find(_i => _i.value === i) || {}).name || []
            }).join('，')
          }
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    // formartLevelName(row, column, cellValue, index){
    // 	var obj = this.levels.find(function(item) {
    // 		if (item.value === row.level) { //
    // 			return item
    // 		}
    // 	})
    // 	if (obj !== undefined) {
    // 		return obj.name;
    // 	} else {
    // 		return "";
    // 	}
    // },
    formartTyepName(row, column, cellValue, index) {
      var obj = this.types.find(function (item) {
        if (item.value === row.type) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.drag-resize {
  background: transparent;
}
.name-total {
  display: flex;
  justify-content: space-between;
  align-items: center;
  box-sizing: border-box;
  padding: 10px;
  border-bottom: 1px solid #ebeef5;
  color: #606266;
  cursor: pointer;
  &:hover {
    background-color: #f5f7fa;
  }
  .name {
    flex: 1;
  }
  .total {
    width: fit-content;
    text-align: center;
    padding-left: 10px;
  }
}
.active-item {
  background-color: #d9e4f4 !important;
}
.type-tag {
  margin: 0 2px;
}
</style>
